==> pegasus-merchandise-api-2.1.1-sources.jar: com/thebeastshop/pegasus/merchandise/vo/OpMainProdVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by gensheng,ye on 2018/12/21.
 */
public class OpMainProdVO implements Serializable {

    private Integer id;
    private Integer productId;
    private String productCode;
    private Integer detailBigimgSeq;
    private String status;
    private String createUsername;
    private String createNickname;
    private Date createTime;
    private Date updateTime;
    private String productNameCN;
    private String detailBigimg;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getProductId() {
        return productId;
    }

    public void setProductId(Integer productId) {
        this.productId = productId;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public Integer getDetailBigimgSeq() {
        return detailBigimgSeq;
    }

    public void setDetailBigimgSeq(Integer detailBigimgSeq) {
        this.detailBigimgSeq = detailBigimgSeq;
    }
    
    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getCreateUsername() {
        return createUsername;
    }

    public void setCreateUsername(String createUsername) {
        this.createUsername = createUsername;
    }

    public String getCreateNickname() {
        return createNickname;
    }

    public void setCreateNickname(String createNickname) {
        this.createNickname = createNickname;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public String getProductNameCN() {
        return productNameCN;
    }

    public void setProductNameCN(String productNameCN) {
        this.productNameCN = productNameCN;
    }

    public String getDetailBigimg() {
        return detailBigimg;
    }

    public void setDetailBigimg(String detailBigimg) {
        this.detailBigimg = detailBigimg;
    }
}

==> pegasus-merchandise-api-3.8.1-sources.jar: com/thebeastshop/pegasus/merchandise/vo/OpMainProdVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;
import java.util.Set;

/**
 * Created by gensheng,ye on 2018/12/21.
 */
public class OpMainProdVO implements Serializable {

    private Integer id;
    private Integer productId;
    private String productCode;
    private Integer detailBigimgSeq;
    private String status;
    private String createUsername;
    private String createNickname;
    private Date createTime;
    private Date updateTime;
    private String productNameCN;
    private String detailBigimg;
    private Set<String> frontCategories;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getProductId() {
        return productId;
    }

    public void setProductId(Integer productId) {
        this.productId = productId;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public Integer getDetailBigimgSeq() {
        return detailBigimgSeq;
    }

    public void setDetailBigimgSeq(Integer detailBigimgSeq) {
        this.detailBigimgSeq = detailBigimgSeq;
    }
    
    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getCreateUsername() {
        return createUsername;
    }

    public void setCreateUsername(String createUsername) {
        this.createUsername = createUsername;
    }

    public String getCreateNickname() {
        return createNickname;
    }

    public void setCreateNickname(String createNickname) {
        this.createNickname = createNickname;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public String getProductNameCN() {
        return productNameCN;
    }

    public void setProductNameCN(String productNameCN) {
        this.productNameCN = productNameCN;
    }

    public String getDetailBigimg() {
        return detailBigimg;
    }

    public void setDetailBigimg(String detailBigimg) {
        this.detailBigimg = detailBigimg;
    }

    public Set<String> getFrontCategories() {
        return frontCategories;
    }

    public void setFrontCategories(Set<String> frontCategories) {
        this.frontCategories = frontCategories;
    }
}
